@@ -4,7 +4,7 @@ use warnings;
 
 use overload '""' => sub { shift->to_string }, fallback => 1;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 require Time::Local;
 
@@ -180,7 +180,7 @@ sub granularity {
   return $self->{granularity} unless @_;
 
   # Set granularity if valid
-  if (defined $_[0] && $_[0] ~~ [0 .. 4]) {
+  if (defined $_[0] && grep { $_[0] == $_ } 0 .. 4) {
 
     # Fine to set
     $self->{granularity} = shift;
